# TODO: vmaf
#
# Conditional build:
%bcond_without	asm		# assembler
%bcond_with	svt_hevc	# SVT-HEVC Encoder support
%bcond_with	vmaf		# VMAF support

%ifarch %{arm}
%define		with_asm	1
%endif

Summary:	H.265/HEVC video encoder
Summary(pl.UTF-8):	Koder obrazu H.265/HEVC
Name:		x265
Version:	4.0
Release:	1
License:	GPL v2+
Group:		Libraries
# some versions also at
#Source0:	https://download.videolan.org/videolan/x265/%{name}_%{version}.tar.gz
#Source0Download: https://bitbucket.org/multicoreware/x265_git/downloads/
Source0:	https://bitbucket.org/multicoreware/x265_git/downloads/%{name}_%{version}.tar.gz
# Source0-md5:	44e0082a7635eab2488bebd18875a09a
Patch0:		%{name}-opt.patch
Patch1:		%{name}-x32.patch
Patch2:		%{name}-arm_flags.patch
Patch3:		%{name}-vmaf.patch
URL:		https://www.x265.org/
BuildRequires:	cmake >= 2.8.11
BuildRequires:	libstdc++-devel >= 6:4.8
BuildRequires:	numactl-devel >= 2
BuildRequires:	rpmbuild(macros) >= 2.007
%if %{with asm}
%ifarch %{ix86} %{x8664} x32
BuildRequires:	nasm >= 2.13.0
%endif
%endif
%{?with_svt_hevc:BuildRequires:	svt-hevc-devel}
%{?with_vmaf:BuildRequires:	vmaf-devel}
Requires:	libx265 = %{version}-%{release}
# see CMakeLists.txt, more is probably possible
ExclusiveArch:	%{ix86} %{x8664} x32 %{arm} ppc64 ppc64le aarch64
# needs 64-bit atomic compare and swap
ExcludeArch:	i386 i486
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
H.265/HEVC video encoder.

%description -l pl.UTF-8
Koder obrazu H.265/HEVC.

%package -n libx265
Summary:	H.265/HEVC video encoder library
Summary(pl.UTF-8):	Biblioteka kodowania obrazu H.265/HEVC
Group:		Libraries

%description -n libx265
H.265/HEVC video encoder library.

%description -n libx265 -l pl.UTF-8
Biblioteka kodowania obrazu H.265/HEVC.

%package -n libx265-devel
Summary:	Header files for x265 library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki x265
Group:		Development/Libraries
Requires:	libstdc++-devel >= 6:4.8
Requires:	libx265 = %{version}-%{release}
Requires:	numactl-devel >= 2

%description -n libx265-devel
Header files for x265 library.

%description -n libx265-devel -l pl.UTF-8
Pliki nagłówkowe biblioteki x265.

%package -n libx265-static
Summary:	Static x265 library
Summary(pl.UTF-8):	Statyczna biblioteka x265
Group:		Development/Libraries
Requires:	libx265-devel = %{version}-%{release}

%description -n libx265-static
Static x265 library.

%description -n libx265-static -l pl.UTF-8
Statyczna biblioteka x265.

%prep
%setup -q -n %{name}_%{version}
%patch0 -p1
%patch1 -p1
%ifarch %{arm} aarch64
%patch2 -p1
%endif
%patch3 -p1

%build
install -d source/build
cd source/build
%ifarch %{arm} aarch64
export CFLAGS="%{rpmcflags} -fPIC"
export CXXFLAGS="%{rpmcxxflags} -fPIC"
%ifarch %{arm_with_neon}
export CFLAGS="$CFLAGS -DHAVE_NEON"
export CXXFLAGS="$CXXFLAGS -DHAVE_NEON"
%endif
%ifarch aarch64
export CFLAGS="$CFLAGS -flax-vector-conversions"
export CXXFLAGS="$CXXFLAGS -flax-vector-conversions"
%endif
%endif
%cmake .. \
	-DENABLE_ASSEMBLY=%{!?with_asm:OFF}%{?with_asm:ON} \
	-DENABLE_HDR10_PLUS=ON \
	%{?with_vmaf:-DENABLE_LIBVMAF=ON} \
	-DENABLE_SHARED=ON \
	%{?with_svt_hevc:-DENABLE_SVT_HEVC=ON} \
	-DLIB_INSTALL_DIR=%{_lib}

%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} -C source/build install \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%post	-n libx265 -p /sbin/ldconfig
%postun	-n libx265 -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc doc/reST/cli.rst
%attr(755,root,root) %{_bindir}/x265

%files -n libx265
%defattr(644,root,root,755)
%doc doc/reST/introduction.rst
%attr(755,root,root) %{_libdir}/libx265.so.212
%attr(755,root,root) %{_libdir}/libhdr10plus.so

%files -n libx265-devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libx265.so
%{_includedir}/hdr10plus.h
%{_includedir}/x265.h
%{_includedir}/x265_config.h
%{_pkgconfigdir}/x265.pc

%files -n libx265-static
%defattr(644,root,root,755)
%{_libdir}/libhdr10plus.a
%{_libdir}/libx265.a
%changelog
* Sat Sep 14 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/x265.git;a=log;h=master

* Sat Sep 14 2024 Jakub Bogusz <qboosh@pld-linux.org> 3c3c065
- updated to 4.0 (ABI 212), added vmaf linking fix and svt_hevc bcond

* Mon May 27 2024 Jan Palus <atler@pld-linux.org> e80ad00
- update arm flags handling

* Sat May 25 2024 Jakub Bogusz <qboosh@pld-linux.org> 2e7fcc3
- updated to 3.6 (ABI 209)

* Wed Jun 30 2021 Jan Palus <atler@pld-linux.org> 62922eb
- don't make ENABLE_ASSEMBLY x86 exclusive

* Wed Jun 30 2021 Jan Palus <atler@pld-linux.org> ee43388
- fix compiler flags on arm

* Sun Jun 27 2021 Jakub Bogusz <qboosh@pld-linux.org> 2d590a7
- updated to 3.5 (new soname)

* Sat Apr 24 2021 Jakub Bogusz <qboosh@pld-linux.org> a06a63e
- removed outdated bitbucket URL

* Mon May 11 2020 Jan Palus <atler@pld-linux.org> ccce368
- add aarch64 to list of supported archs

* Mon Mar 09 2020 Jakub Bogusz <qboosh@pld-linux.org> 4264b29
- updated to 3.2.1

* Sat Oct 26 2019 Jakub Bogusz <qboosh@pld-linux.org> e745f1c
- updated to 3.2 (ABI 179)

* Mon Jul 22 2019 Jakub Bogusz <qboosh@pld-linux.org> c1aa584
- updated to 3.1.1 (ABI 176)

* Wed Mar 13 2019 Jan Rękorajski <baggins@pld-linux.org> 01bbdd5
- release 2 (by relup.sh)

* Sat Feb 16 2019 Jakub Bogusz <qboosh@pld-linux.org> 94469a9
- updated to 3.0 (ABI 169)

* Wed Oct 31 2018 Jakub Bogusz <qboosh@pld-linux.org> 5afc8bc
- updated to 2.9 (note: new soname)
- updated x32 patch

* Sat Dec 23 2017 Jakub Bogusz <qboosh@pld-linux.org> 1d3acdc
- updated to 2.6 (note: new soname)

* Sun Jul 16 2017 Jakub Bogusz <qboosh@pld-linux.org> a827c98
- updated to 2.5 (ABI 130)

* Wed May 24 2017 Jakub Bogusz <qboosh@pld-linux.org> a8d1efd
- updated to 2.4 (note: new soname, ABI 116)

* Sat Oct 08 2016 Jakub Bogusz <qboosh@pld-linux.org> dcd66c3
- updated to 2.1 (note: new soname)

* Sat Feb 20 2016 Jakub Bogusz <qboosh@pld-linux.org> 52bf8e6
- updated to 1.9 (note: new soname)

* Thu Oct 15 2015 Jakub Bogusz <qboosh@pld-linux.org> c14ed13
- added x32 patch, asm could be enabled on x32 now

